@@ -1,7 +1,7 @@
 package Bencher;
 
 our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -921,12 +921,15 @@ sub format_result {
             $rit->{time} = sprintf(
                 "%.${num_significant_digits}g%s",
                 $rit->{time} * $factor, $unit);
-            $rit->{rate} = sprintf(
-                "%.${num_significant_digits}g", $rit->{rate});
+            if (exists $rit->{rate}) {
+                $rit->{rate} = sprintf(
+                    "%.${num_significant_digits}g", $rit->{rate});
+            }
             $rit->{errors} = sprintf("%.2g", $rit->{errors});
             if (exists $rit->{mod_overhead_time}) {
                 $rit->{mod_overhead_time} = sprintf(
-                    "%.5f%s", $rit->{mod_overhead_time} * $factor, $unit);
+                    "%.${num_significant_digits}g%s",
+                    $rit->{mod_overhead_time} * $factor, $unit);
             }
         }
     }
@@ -1542,7 +1545,7 @@ sub bencher {
                     ${"$mod\::VERSION"};
             }
             $envres->[3]{'func.sysload_before'} = [Sys::Load::getload()];
-            $envres->[3]{'_time_start'} = Time::HiRes::time();
+            $envres->[3]{'func.time_start'} = Time::HiRes::time();
         }
 
         my $tres = Benchmark::Dumb::_timethese_guts(
@@ -1554,9 +1557,9 @@ sub bencher {
         );
 
         if ($return_resmeta) {
+            $envres->[3]{'func.time_end'} = Time::HiRes::time();
             $envres->[3]{'func.elapsed_time'} =
-                Time::HiRes::time() - $envres->[3]{'_time_start'};
-            delete $envres->[3]{'_time_start'};
+                $envres->[3]{'func.time_end'} - $envres->[3]{'func.time_start'};
             $envres->[3]{'func.sysload_after'} = [Sys::Load::getload()];
         }
 
@@ -1572,7 +1575,7 @@ sub bencher {
             };
         }
         $envres->[3]{'table.fields'} =
-            [qw/seq name rate time samples errors/];
+            [qw/seq name rate time errors samples/];
 
         if ($parsed->{after_bench}) {
             $log->infof("Executing after_bench hook ...");
@@ -1653,7 +1656,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.21 of Bencher (from Perl distribution Bencher), released on 2016-01-05.
+This document describes version 0.22 of Bencher (from Perl distribution Bencher), released on 2016-01-05.
 
 =head1 SYNOPSIS
 
